<?php 
/**
 * The template for functions 
 *
 * @version    0.1.2
 * @package    plied
 * @author     Zidithemes
 * @copyright  Copyright (C) 2020 zidithemes.tumblr.com. All Rights Reserved.
 * @license    GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 *
 * 
 */


if ( ! defined( 'ABSPATH' ) ) { exit; }

require get_template_directory() . "/inc/plied-options.php";

function plied_setup(){


	// ADD THEME SUPPORT
	add_theme_support( 'title-tag' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( "custom-header" );
	add_theme_support( "custom-background" );
	add_theme_support( 'post-thumbnails' );
	add_theme_support('woocommerce');


	//ADD IMAGE SIZES
	add_image_size( 'large', 590, 9999 );
	add_image_size('featured', 400, 250);
	add_image_size( 'medium', 800, 240 );

	// ADD EDITOR STYLE

	register_nav_menus(
	    array(
	      'primary-menu' => esc_attr__( 'Primary Menu', 'plied' ),
	    )
	  );

	// SET CONTENT WIDTH
	if ( ! isset( $content_width ) ) $content_width = 600;

}

add_action('after_setup_theme', 'plied_setup');





if (!function_exists('plied_admin_style')) {
	function plied_admin_style($hook) {
		
		if ('appearance_page_plied_theme_info_options' === $hook) {
			wp_enqueue_style('plied-admin-script-style', get_template_directory_uri() . '/css/plied-admin.css');
		}
	}
}
add_action('admin_enqueue_scripts', 'plied_admin_style');



// Load styles
function plied_load_styles_scripts(){
	// NOTE:   SOME OF THESE SCRIPTS ARE HOSTED ON A CDN AND ARE NOT STORED LOCALLY... SO THIS THEME MAY NOT RENDER PROPERLY IF YOU ARE NOT CONNECTED TO THE INTERNET
	
		wp_enqueue_style( 'style', get_template_directory_uri() . '/style.css');

		wp_enqueue_style( 'google-noto-font', 'https://fonts.googleapis.com/css?family=Noto+Sans');

		wp_enqueue_script('plied-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js' );
		
		if ( is_singular() ) wp_enqueue_script( "comment-reply" );
	
}

add_action('wp_enqueue_scripts', 'plied_load_styles_scripts');



function plied_pingback_wrap() {

		if ( is_singular() && pings_open() ) {
			echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
		}

}
add_action( 'wp_head', 'plied_pingback_wrap' );










// Creating the sidebar
function plied_menu_init() {


register_sidebar(
		array(
                'name' 			=> esc_html__('Sidebar Widgets', 'plied'),
                'id'    		=> 'sidebar_id',
                'class'       	=> '',
				'description' 	=> esc_html__('Add sidebar widgets here', 'plied'),
				'before_widget' => '<div class="sidebar-items">',
				'after_widget' 	=> '</div>',
				'before_title' 	=> '<h2>',
				'after_title' 	=> '</h2>',
	));


register_sidebar(
		array(
                'name' 			=> esc_html__('Left Sidebar', 'plied'),
                'id'    		=> 'left_sidebar',
                'class'       	=> '',
				'description' 	=> esc_html__('Add left sidebar widgets here', 'plied'),
				'before_widget' => '<div class="sidebar-items">',
				'after_widget' 	=> '</div>',
				'before_title' 	=> '<h2>',
				'after_title' 	=> '</h2>',
	));

	register_sidebar(array(
                'name' 			=> esc_html__('Left Footer', 'plied'),
                'id'    		=> 'left_footer',
                'class' 		=> '',
				'description' 	=> esc_html__('Add widgets here', 'plied'),
				'before_widget' => '<li>',
				'after_widget' 	=> '</li>',
				'before_title' 	=> '<h2>',
				'after_title' 	=> '</h2>',
	));
	
	register_sidebar(array(
                'name' 			=> esc_html__('Middle Footer', 'plied'),
                'id'    		=> 'middle_footer',
                'class' 		=> '',
				'description' 	=> esc_html__('Add widgets here', 'plied'),
				'before_widget' => '<li>',
				'after_widget' 	=> '</li>',
				'before_title'	=> '<h2>',
				'after_title' 	=> '</h2>',
	));
	
	register_sidebar(array(
                'name' 			=> esc_html__('Right Footer', 'plied'),
                'id'    		=> 'right_footer',
                'class' 		=> '',
				'description' 	=> esc_html__('Add widgets here', 'plied'),
				'before_widget' => '<li>',
				'after_widget' 	=> '</li>',
				'before_title' 	=> '<h2>',
				'after_title' 	=> '</h2>',
	));
	
	register_sidebar(array(
                'name' 			=> esc_html__('Fourth Footer', 'plied'),
                'id'    		=> 'fourth_footer',
                'class' 		=> '',
				'description' 	=> esc_html__('Add widgets here', 'plied'),
				'before_widget' => '<li>',
				'after_widget' 	=> '</li>',
				'before_title' 	=> '<h2>',
				'after_title' 	=> '</h2>',
	));

	register_sidebar(array(
                'name' 			=> esc_html__('Full Width Footer', 'plied'),
                'id'    		=> 'full_width_footer',
                'class' 		=> '',
				'description' 	=> esc_html__('Add widgets here', 'plied'),
				'before_widget' => '<li>',
				'after_widget' 	=> '</li>',
				'before_title' 	=> '<h2>',
				'after_title' 	=> '</h2>',
	));

}
add_action('widgets_init', 'plied_menu_init');

// this increases or decreaes the length of the excerpt on the index page
function plied_excerpt_length( $length ) {
	if ( is_admin() ) {
		return $length;
	}
	return 20;
}
add_filter( 'excerpt_length', 'plied_excerpt_length', 999 );

function plied_excerpt_more( $more ) {
    //return 'More';
    return ' <a class="read-more" href="'. esc_url(get_permalink( get_the_ID() ) ) . '">' . esc_attr__('Read More', 'plied') . '</a>';
}
add_filter( 'excerpt_more', 'plied_excerpt_more' );





/**
 * Fix skip link focus in IE11.
 *
 * This does not enqueue the script because it is tiny and because it is only for IE11,
 * thus it does not warrant having an entire dedicated blocking script being loaded.
 *
 * @link https://git.io/vWdr2
 */
function plied_skip_link_focus_fix() {
	// The following is minified via `terser --compress --mangle -- js/skip-link-focus-fix.js`.
	?>
	<script>
	/(trident|msie)/i.test(navigator.userAgent)&&document.getElementById&&window.addEventListener&&window.addEventListener("hashchange",function(){var t,e=location.hash.substring(1);/^[A-z0-9_-]+$/.test(e)&&(t=document.getElementById(e))&&(/^(?:a|select|input|button|textarea)$/i.test(t.tagName)||(t.tabIndex=-1),t.focus())},!1);
	</script>
	<?php
}
add_action( 'wp_print_footer_scripts', 'plied_skip_link_focus_fix' );

